# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = 'libzim'
copyright = '2020, libzim-team'
author = 'libzim-team'


# -- General configuration ---------------------------------------------------

on_rtd = os.environ.get('READTHEDOCS', None) == 'True'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'breathe',
    'exhale'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']


if not on_rtd:
    html_theme = 'sphinx_rtd_theme'

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

breathe_projects = {
    "libzim": "./xml"
}
breathe_default_project = 'libzim'

exhale_args = {
    "containmentFolder":   "./api",
    "rootFileName":        "ref_api.rst",
    "rootFileTitle":       "Reference API",
    "doxygenStripFromPath":"..",
    "treeViewIsBootstrap": True,
    "createTreeView" : True,
    "exhaleExecutesDoxygen": True,
    "exhaleDoxygenStdin":    "INPUT = ../include"
}

primary_domain = 'cpp'

highlight_language = 'cpp'



#!/usr/bin/env python3

'''
Copyright 2021 Matthieu Gautier <mgautier@kymeria.fr>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or any
later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301, USA.
'''

import argparse
from pathlib import Path
from urllib import request
from urllib.error import *
import tarfile
import sys

TEST_DATA_VERSION = "0.3"
ARCHIVE_URL_TEMPL = "https://github.com/openzim/zim-testing-suite/releases/download/v{version}/zim-testing-suite-{version}.tar.gz"

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument('--version', '-v',
                        help="The version to download.",
                        default=TEST_DATA_VERSION)
    parser.add_argument('--remove-top-dir',
                        help="Remove the top directory when extracting",
                        action='store_true')
    parser.add_argument('outdir',
                        help='The directory where to install the test data.')
    args = parser.parse_args()

    test_data_url = ARCHIVE_URL_TEMPL.format(version=args.version)

    try:
        with request.urlopen(test_data_url) as f:
            with tarfile.open(fileobj=f, mode="r|*") as archive:
                while True:
                    member = archive.next()
                    if member is None:
                        break
                    if args.remove_top_dir:
                        member.name = '/'.join(member.name.split('/')[1:])
                    archive.extract(member, path=args.outdir)

    except HTTPError as e:
        print("Error downloading archive at url : {}".format(test_data_url))
        print(e)
        sys.exit(1)
    except OSError as e:
        print("Error writing the test data on the file system.")
        print(e)
        sys.exit(1)
